@@ -291,7 +291,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                 exp_token += bytes({i})
                 exp_token += bytes(1)
             token_struct = struct.pack("=i", len(exp_token)) + exp_token
-            cstr_parts['attrs_before'] = {1256: bytearray(token_struct)}
+            # cstr_parts['attrs_before'] = {1256: bytearray(token_struct)}
         elif user:
             cstr_parts['UID'] = user
             cstr_parts['PWD'] = password
@@ -313,9 +313,10 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         # if options.get('extra_params', None):
         #     connstr += ';' + options['extra_params']
         print('connection String--> ', connstr)
-        import re
-        connstr = re.sub('attrs_before.*?};', '', connstr)
-        print('after connection String--> ', connstr)
+        # import re
+        # connstr = re.sub('attrs_before.*?};', '', connstr)
+        # print('after connection String--> ', connstr)
+        cstr_parts['attrs_before'] = {1256: bytearray(token_struct)}
         print('atts_before Key: ',cstr_parts['attrs_before'])
         unicode_results = options.get('unicode_results', False)
         timeout = options.get('connection_timeout', 0)
